@@ -8,7 +8,8 @@ test_that(
   {
     expect_known_output(
       object = print(dmdScheme_example(), printAttr = FALSE, printExtAttr = FALSE, printData = FALSE, width = 300),
-      file = "ref-07-print.dmdScheme.FFF.txt"
+      file = "ref-07-print.dmdScheme.FFF.txt",
+      update = TRUE
     )
   }
 )
@@ -18,7 +19,8 @@ test_that(
   {
     expect_known_output(
       object = print(dmdScheme_example(), printAttr = TRUE, printExtAttr = FALSE, printData = FALSE, width = 300),
-      file = "ref-07-print.dmdScheme.TFF.txt"
+      file = "ref-07-print.dmdScheme.TFF.txt",
+      update = TRUE
     )
   }
 )
@@ -28,7 +30,8 @@ test_that(
   {
     expect_known_output(
       object = print(dmdScheme_example(), printAttr = TRUE, printExtAttr = TRUE, printData = FALSE, width = 300),
-      file = "ref-07-print.dmdScheme.TTF.txt"
+      file = "ref-07-print.dmdScheme.TTF.txt",
+      update = TRUE
     )
   }
 )
@@ -38,7 +41,8 @@ test_that(
   {
     expect_known_output(
       object = print(dmdScheme(), printAttr = TRUE, printExtAttr = TRUE, printData = TRUE, width = 300),
-      file = "ref-07-print.dmdScheme.TTT.txt"
+      file = "ref-07-print.dmdScheme.TTT.txt",
+      update = TRUE
     )
   }
 )
@@ -48,7 +52,8 @@ test_that(
   {
     expect_known_output(
       object = print(dmdScheme(), printAttr = TRUE, printExtAttr = TRUE, printData = TRUE, width = 300),
-      file = "ref-07-print.dmdScheme.TTT.EMPTY.txt"
+      file = "ref-07-print.dmdScheme.TTT.EMPTY.txt",
+      update = TRUE
     )
   }
 )
